package com.example.aeropuertoback.controller;

import com.example.aeropuertoback.dao.ItinerarioRepository;
import com.example.aeropuertoback.entity.*;
import com.example.aeropuertoback.service.aeropuerto.IAeropuertoService;
import com.example.aeropuertoback.service.escala.IEscalaService;
import com.example.aeropuertoback.service.vuelo.IVueloService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@CrossOrigin(origins = "http://localhost:4200")
@RestController
@RequestMapping(value = "/escalas")
public class EscalaController {

    @Autowired
    private IEscalaService escalaService;

    @Autowired
    private IAeropuertoService aeropuertoService;

    @Autowired
    private IVueloService vueloService;

    @Autowired
    private ItinerarioRepository itinerarioRepository;

    @GetMapping(value = "/listar")
    public List<Escala> listar(){
        return escalaService.findAll();
    }

    @PostMapping(value = "/agregar", consumes = MediaType.APPLICATION_JSON_VALUE)
    public Escala guardarVuelo(@RequestBody Escala escala){
        Aeropuerto aeropuertoOrigen = aeropuertoService.findOne(escala.getCodigoAeropuertoOrigen().getId());
        Aeropuerto aeropuertoDestino = aeropuertoService.findOne(escala.getCodigoAeropuertoDestino().getId());
        Vuelo vuelo = vueloService.findOne(escala.getCodigoVuelo().getId());
        escala.setCodigoAeropuertoOrigen(aeropuertoOrigen);
        escala.setCodigoAeropuertoDestino(aeropuertoDestino);
        escala.setCodigoVuelo(vuelo);
        return escalaService.save(escala);
    }

    @GetMapping("listar/{id}/vuelos")
    public List<Escala> listarVuelosByEscalas(@PathVariable Integer id){
        List<Escala> escala = vueloService.findOne(id).getEscalas();

        return escala;
    }

    @PostMapping("/reserva/{id}")
    public Escala addEscala(@PathVariable(value = "id") Integer id, @RequestBody Escala escalaRequest) {
        Escala escala = itinerarioRepository.findById(id).map(itinerarioReserva -> {
            Integer escalaId = escalaRequest.getId();
            Escala _esc = escalaService.findOne(escalaId);
            itinerarioReserva.addEscala(_esc);
            itinerarioRepository.save(itinerarioReserva);
            return _esc;
        }).orElseThrow(null);

        return escala;
    }

    @DeleteMapping(value="/eliminar/{id}")
    public void eliminarEscala(@PathVariable Integer id){
        escalaService.delete(id);
    }

    @GetMapping("escala/{id}")
    public Integer getVueloByEscalaId(@PathVariable Integer id){
        return escalaService.findOne(id).getCodigoVuelo().getId();
    }

}
