package com.example.aeropuertoback.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.persistence.*;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Entity
@Table(name="legs")
public class Escala {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Integer id;

    @Column(name="actual_departure_time")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fechaSalida;

    @Column(name="actual_arrival_time")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fechaLlegada;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "origin_airport_code")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Aeropuerto codigoAeropuertoOrigen;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "destination_airport_code")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Aeropuerto codigoAeropuertoDestino;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "flight_number")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Vuelo codigoVuelo;

    @ManyToMany(fetch = FetchType.LAZY,
            cascade = {
                    CascadeType.PERSIST,
                    CascadeType.MERGE,
                    CascadeType.ALL
            },
            mappedBy = "escalas")
    @JsonIgnore
    private List<ItinerarioReserva> itinerarioReserva;

    public Escala(){
        itinerarioReserva = new ArrayList<>();
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Aeropuerto getCodigoAeropuertoOrigen() {
        return codigoAeropuertoOrigen;
    }

    public void setCodigoAeropuertoOrigen(Aeropuerto codigoAeropuertoOrigen) {
        this.codigoAeropuertoOrigen = codigoAeropuertoOrigen;
    }

    public Aeropuerto getCodigoAeropuertoDestino() {
        return codigoAeropuertoDestino;
    }

    public void setCodigoAeropuertoDestino(Aeropuerto codigoAeropuertoDestino) {
        this.codigoAeropuertoDestino = codigoAeropuertoDestino;
    }

    public Vuelo getCodigoVuelo() {
        return codigoVuelo;
    }

    public void setCodigoVuelo(Vuelo codigoVuelo) {
        this.codigoVuelo = codigoVuelo;
    }

    public String getAeropuertoOrigen(){
        return this.getCodigoAeropuertoOrigen().getCodigo();
    }

    public String getAeropuertoDestino(){
        return this.getCodigoAeropuertoDestino().getCodigo();
    }

    public Date getFechaSalida() {
        return fechaSalida;
    }

    public void setFechaSalida(Date fechaSalida) {
        this.fechaSalida = fechaSalida;
    }

    public Date getFechaLlegada() {
        return fechaLlegada;
    }

    public void setFechaLlegada(Date fechaLlegada) {
        this.fechaLlegada = fechaLlegada;
    }

    public List<ItinerarioReserva> getItinerarioReserva() {
        return itinerarioReserva;
    }

    public void setItinerarioReserva(List<ItinerarioReserva> itinerarioReserva) {
        this.itinerarioReserva = itinerarioReserva;
    }

    public double getCosto(){
        return codigoVuelo.getCosto();
    }

}

