package com.example.aeropuertoback.entity;

import com.fasterxml.jackson.annotation.JsonProperty;
import org.springframework.format.annotation.DateTimeFormat;
import javax.persistence.*;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Entity
@Table(name="itinerary_reservations")
public class ItinerarioReserva {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "reservation_id", nullable = false)
    private Integer id;

    @Column(name="date_reservation_made")
    @Temporal(TemporalType.DATE)
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date diaReservacion;

    @Column(name="reservation_status_code")
    private String estado;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "pasajero_id")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Pasajero pasajero;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "agente_id")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private AgenteReserva agente;

    @ManyToMany(fetch = FetchType.LAZY,
            cascade = {
                    CascadeType.PERSIST,
                    CascadeType.MERGE
            })
    @JoinTable(name = "reservation_payments",
            joinColumns = { @JoinColumn(name = "reservation_id") },
            inverseJoinColumns = { @JoinColumn(name = "payment_id") })
    private List<Pago> pagos;

    @ManyToMany(fetch = FetchType.LAZY,
            cascade = {
                    CascadeType.PERSIST,
                    CascadeType.MERGE,
                    CascadeType.ALL
            })
    @JoinTable(name = "itinerary_legs",
            joinColumns = { @JoinColumn(name = "reservation_id") },
            inverseJoinColumns = { @JoinColumn(name = "leg_id") })
    private List<Escala> escalas;

    public ItinerarioReserva(){
        pagos = new ArrayList<>();
        escalas = new ArrayList<>();
    }

    @PrePersist
    public void prePersist(){
        diaReservacion = new Date();
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Date getDiaReservacion() {
        return diaReservacion;
    }

    public void setDiaReservacion(Date diaReservacion) {
        this.diaReservacion = diaReservacion;
    }

    public Pasajero getPasajero() {
        return pasajero;
    }

    public void setPasajero(Pasajero pasajero) {
        this.pasajero = pasajero;
    }

    public AgenteReserva getAgente() {
        return agente;
    }

    public void setAgente(AgenteReserva agente) {
        this.agente = agente;
    }

    public List<Pago> getPagos() {
        return pagos;
    }

    public void setPagos(List<Pago> pagos) {
        this.pagos = pagos;
    }

    public void addPago(Pago pago) {
        this.pagos.add(pago);
        pago.getItinerarioReserva().add(this);
    }

    public String getEstado() {
        return estado;
    }

    public void setEstado(String estado) {
        this.estado = estado;
    }

    public List<Escala> getEscalas() {
        return escalas;
    }

    public void setEscalas(List<Escala> escalas) {
        this.escalas = escalas;
    }
    public void addEscala(Escala escala) {
        this.escalas.add(escala);
        escala.getItinerarioReserva().add(this);
    }

    public Integer getPasajeroId(){
        return pasajero.getId();
    }

    public Integer getAgenteId(){
        return agente.getId();
    }

    public String getAgenteNombre(){
        return agente.getNombre();
    }

    public String getPasajeroNombre(){
        return pasajero.getPrimerNombre();
    }

}

