package com.example.aeropuertoback.entity;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.persistence.*;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

@Entity
@Table(name="passengers")
public class Pasajero implements Serializable {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Integer id;

    @Column(name="first_name")
    private String primerNombre;

    @Column(name="second_name")
    private String segundoNombre;

    @Column(name="last_name")
    private String apellido;

    @Column(name="phone_number")
    private String telefono;

    @Column(name="email_address")
    private String correo;

    @Column(name="address_lines")
    private String direccion;

    @Column(name="city")
    private String ciudad;

    @Column(name="state_province_country")
    private String provincia;

    @Column(name="country")
    private String pais;

    @Column(name="other_passenger_details")
    private String detalles;

    @OneToMany(mappedBy = "pasajero", cascade = CascadeType.ALL)
    private List<ItinerarioReserva> itinerarioReservas;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "pasajero_auth_id")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private PasajeroAuth pasajeroAuth;

    private static final long serialVersionUID = 1L;

    public Pasajero() {
        itinerarioReservas = new ArrayList<ItinerarioReserva>();
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getPrimerNombre() {
        return primerNombre;
    }

    public void setPrimerNombre(String primerNombre) {
        this.primerNombre = primerNombre;
    }

    public String getSegundoNombre() {
        return segundoNombre;
    }

    public void setSegundoNombre(String segundoNombre) {
        this.segundoNombre = segundoNombre;
    }

    public String getApellido() {
        return apellido;
    }

    public void setApellido(String apellido) {
        this.apellido = apellido;
    }

    public String getTelefono() {
        return telefono;
    }

    public void setTelefono(String telefono) {
        this.telefono = telefono;
    }

    public String getCorreo() {
        return correo;
    }

    public void setCorreo(String correo) {
        this.correo = correo;
    }

    public String getDireccion() {
        return direccion;
    }

    public void setDireccion(String direccion) {
        this.direccion = direccion;
    }

    public String getCiudad() {
        return ciudad;
    }

    public void setCiudad(String ciudad) {
        this.ciudad = ciudad;
    }

    public String getProvincia() {
        return provincia;
    }

    public void setProvincia(String provincia) {
        this.provincia = provincia;
    }

    public String getPais() {
        return pais;
    }

    public void setPais(String pais) {
        this.pais = pais;
    }

    public String getDetalles() {
        return detalles;
    }

    public void setDetalles(String detalles) {
        this.detalles = detalles;
    }

    public List<ItinerarioReserva> getItinerarioReservas() {
        return itinerarioReservas;
    }

    public void setItinerarioReserva(List<ItinerarioReserva> itinerarioReserva) {
        this.itinerarioReservas = itinerarioReserva;
    }

    public void addReserva(ItinerarioReserva itinerarioReserva){
        this.itinerarioReservas.add(itinerarioReserva);
    }

    public void setItinerarioReservas(List<ItinerarioReserva> itinerarioReservas) {
        this.itinerarioReservas = itinerarioReservas;
    }

    public PasajeroAuth getPasajeroAuth() {
        return pasajeroAuth;
    }

    public void setPasajeroAuth(PasajeroAuth pasajeroAuth) {
        this.pasajeroAuth = pasajeroAuth;
    }

    public Integer getUserId(){
        return pasajeroAuth.getId();
    }
}
